searchData={"items":[{"type":"module","title":"PhoenixPlayground","doc":"Phoenix Playground makes it easy to create single-file Phoenix applications.","ref":"PhoenixPlayground.html"},{"type":"function","title":"PhoenixPlayground.start/1","doc":"Starts Phoenix Playground.\n\nThis functions starts Phoenix with a LiveView (`:live`), a controller (`:controller`),\nor a router (`:router`).","ref":"PhoenixPlayground.html#start/1"},{"type":"function","title":"Options - PhoenixPlayground.start/1","doc":"* `:live` - a LiveView module.\n\n  * `:controller` - a controller module.\n\n  * `:plug` - a plug.\n\n  * `:port` - port to listen on, defaults to: `4000`.\n\n  * `:open_browser` - whether to open the browser on start, defaults to `true`.\n\n  * `:child_specs` - child specs to run in Phoenix Playground supervision tree. The playground\n    Phoenix endpoint is automatically added and is always the last child spec. Defaults to `[]`.","ref":"PhoenixPlayground.html#start/1-options"},{"type":"module","title":"PhoenixPlayground.Reloader","doc":"","ref":"PhoenixPlayground.Reloader.html"},{"type":"module","title":"PhoenixPlayground.Test","doc":"Conveniences for testing single-file Phoenix apps.","ref":"PhoenixPlayground.Test.html"},{"type":"module","title":"Examples - PhoenixPlayground.Test","doc":"Mix.install([\n      {:phoenix_playground, \"~> 0.1.0\"}\n    ])\n\n    defmodule DemoLive do\n      use Phoenix.LiveView\n\n      def mount(_params, _session, socket) do\n        {:ok, assign(socket, count: 0)}\n      end\n\n      def render(assigns) do\n        ~H\"\"\"\n         Count: <%= @count %>   + \n        \"\"\"\n      end\n\n      def handle_event(\"inc\", _params, socket) do\n        {:noreply, update(socket, :count, &(&1 + 1))}\n      end\n    end\n\n    Logger.configure(level: :info)\n    ExUnit.start()\n\n    defmodule DemoLiveTest do\n      use ExUnit.Case\n      use PhoenixPlayground.Test, live: DemoLive\n\n      test \"it works\" do\n        {:ok, view, html} = live(build_conn(), \"/\")\n\n        assert html =~ \"Count: 0\"\n        assert render_click(view, :inc, %{}) =~ \"Count: 1\"\n        assert render_click(view, :inc, %{}) =~ \"Count: 2\"\n      end\n    end","ref":"PhoenixPlayground.Test.html#module-examples"},{"type":"extras","title":"Phoenix Playground","doc":"# Phoenix Playground\n\n[![CI](https://github.com/phoenix-playground/phoenix_playground/actions/workflows/ci.yml/badge.svg)](https://github.com/phoenix-playground/phoenix_playground/actions/workflows/ci.yml)\n\nPhoenix Playground makes it easy to create single-file [Phoenix](https://www.phoenixframework.org) applications.","ref":"readme.html"},{"type":"extras","title":"Examples - Phoenix Playground","doc":"[![Run in Livebook](https://livebook.dev/badge/v1/blue.svg)](https://livebook.dev/run?url=https%3A%2F%2Fgithub.com%2Fphoenix-playground%2Fphoenix_playground%2Fblob%2Fmain%2Fexamples%2Fdemo_live.livemd)\n\nCreate a `demo_live.exs` file:\n\n```elixir\nMix.install([\n  {:phoenix_playground, \"~> 0.1.0\"}\n])\n\ndefmodule DemoLive do\n  use Phoenix.LiveView\n\n  def mount(_params, _session, socket) do\n    {:ok, assign(socket, count: 0)}\n  end\n\n  def render(assigns) do\n    ~H\"\"\"\n     <%= @count %> \n     + \n     - \n\n     \n      body { padding: 1em; }\n     \n    \"\"\"\n  end\n\n  def handle_event(\"inc\", _params, socket) do\n    {:noreply, assign(socket, count: socket.assigns.count + 1)}\n  end\n\n  def handle_event(\"dec\", _params, socket) do\n    {:noreply, assign(socket, count: socket.assigns.count - 1)}\n  end\nend\n\nPhoenixPlayground.start(live: DemoLive)\n```\n\nand run it:\n\n```\n$ iex demo_live.exs\n```\n\n \n\n\nSee more examples below:\n\n  * [`examples/demo_live.exs`]\n  * [`examples/demo_live_test.exs`]\n  * [`examples/demo_controller.exs`]\n  * [`examples/demo_controller_test.exs`]\n  * [`examples/demo_plug.exs`]","ref":"readme.html#examples"},{"type":"extras","title":"License - Phoenix Playground","doc":"Copyright (c) 2024 Wojtek Mach\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n\n[`examples/demo_live.exs`]: examples/demo_live.exs\n[`examples/demo_live_test.exs`]: examples/demo_live_test.exs\n[`examples/demo_controller.exs`]: examples/demo_controller.exs\n[`examples/demo_controller_test.exs`]: examples/demo_controller_test.exs\n[`examples/demo_plug.exs`]: examples/demo_plug.exs\n\n\n[`examples/demo_controller.exs`]: https://github.com/phoenix-playground/phoenix_playground/blob/v0.1.3/examples/demo_controller.exs\n[`examples/demo_controller_test.exs`]: https://github.com/phoenix-playground/phoenix_playground/blob/v0.1.3/examples/demo_controller_test.exs\n[`examples/demo_live.exs`]: https://github.com/phoenix-playground/phoenix_playground/blob/v0.1.3/examples/demo_live.exs\n[`examples/demo_live_test.exs`]: https://github.com/phoenix-playground/phoenix_playground/blob/v0.1.3/examples/demo_live_test.exs\n[`examples/demo_plug.exs`]: https://github.com/phoenix-playground/phoenix_playground/blob/v0.1.3/examples/demo_plug.exs","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.1.3 (2024-05-16) - Changelog","doc":"* Use state-preserving live reload. (Requires Phoenix LiveView 1.0.0-rc.1+.)\n\n  * Display errors using `Plug.Debugger`.","ref":"changelog.html#v0-1-3-2024-05-16"},{"type":"extras","title":"v0.1.2 (2024-04-29) - Changelog","doc":"* Deprecate setting `:router` in favour of `:plug`.","ref":"changelog.html#v0-1-2-2024-04-29"},{"type":"extras","title":"v0.1.1 (2024-04-23) - Changelog","doc":"* Use local javascript assets.\n\n  * Update secret key base.\n\n  * Replace `PhoenixPlayground.start_link/1` with `start/1`.\n\n  * Fix opening up component definition/caller: set `:debug_heex_annotations` on application boot.\n\n  * Add `:child_specs` option to specify additional processes to run in the supervision tree.\n\n  * Prevent VM from halting when playground is started.","ref":"changelog.html#v0-1-1-2024-04-23"},{"type":"extras","title":"v0.1.0 (2024-04-18) - Changelog","doc":"* Initial release.","ref":"changelog.html#v0-1-0-2024-04-18"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}